# -*- coding: utf-8 -*-

"""
@date: 2020/7/16 下午8:12
@file: registry.py
@author: zj
@description: 
"""

from pnno.util.registry import Registry

ANNOS = Registry()